@@ -4,8 +4,10 @@ QueenbeeTask is a wrapper around luigi.Task which is used by queenbee-local to
 execute Queenbee-specific task. You probably don't need to use this module in your code.
 """
 import logging
+import logging.config
 import subprocess
 import socket
+import pathlib
 import os
 import shutil
 import tempfile
@@ -44,8 +46,26 @@ class QueenbeeTask(luigi.Task):
         * supports piping
     """
 
+    def _get_log_folder(self, folder):
+        """A hack to find the log file!"""
+        folder = pathlib.Path(folder)
+        log_file = pathlib.Path(folder, '__logs__', 'logs.cfg')
+        if log_file.exists():
+            return log_file.as_posix()
+        else:
+            return self._get_log_folder(folder.parent)
+
+    @property
+    def log_config(self):
+        return self._get_log_folder(self.initiation_folder)
+
     def get_interface_logger(self):
         logger = logging.getLogger('luigi-interface')
+        if not logger.handlers:
+            # load the logs from shared config file
+            # This is an issue in Windows with multiple processors
+            # https://github.com/spotify/luigi/issues/2247
+            logging.config.fileConfig(self.log_config)
         return logger
 
     @property
@@ -111,7 +131,10 @@ class QueenbeeTask(luigi.Task):
         logger = self.get_interface_logger()
         for art in self.output_artifacts:
             logger.info(f"copying output artifact: {art['name']}...")
-            _copy_artifacts(os.path.join(src, art['from']), art['to'])
+            try:
+                _copy_artifacts(os.path.join(src, art['from']), art['to'])
+            except Exception:
+                logger.exception(f"Failed to copy output artifact: {art['name']}...")
 
     def _copy_output_parameters(self, src):
         """Copy output parameters to project folder.
@@ -157,8 +180,7 @@ class QueenbeeTask(luigi.Task):
 
     def run(self):
         logger = self.get_interface_logger()
-        # this is a temporary solution until we fix the bug with logging on Windows
-        logs = []
+
         # replace ' with " for Windows systems and vise versa for unix systems
         command = self.command()
         if SYSTEM == 'Windows':
@@ -180,17 +202,15 @@ class QueenbeeTask(luigi.Task):
 
         for line in iter(p.stdout.readline, b''):
             msg = line.decode('utf-8').strip()
-            logs.append(msg)
             logger.info(msg)
 
         p.communicate()
 
         if p.returncode != 0:
-            logger.error(
-                f'Failed task: {self.__class__.__name__}. '
-                'Run the command with --debug key to debug the workflow.'
-            )
-            raise ValueError('\n' + '_' * 20 + '\n' + '\n'.join(logs))
+            err_msg = f'\n\nFailed task: {self.__class__.__name__}.\n' \
+                'Run the command with --debug key to debug the workflow.\n\n'
+            logger.error(err_msg)
+            raise ValueError(err_msg)
 
         # copy the results file back
         self._copy_output_artifacts(dst)
@@ -249,3 +269,41 @@ def local_scheduler():
     finally:
         sock.close()
         return local_schedule
+
+
+LOGS_CONFIG = """
+[formatters]
+keys: default
+
+[loggers]
+keys: root, luigi-interface
+
+[handlers]
+keys: console, logfile
+
+[formatter_default]
+format: %(asctime)s %(levelname)s: %(message)s
+datefmt:%Y-%m-%d %H:%M:%S
+
+[handler_console]
+class: StreamHandler
+args: [sys.stdout,]
+formatter: default
+
+[handler_logfile]
+class: FileHandler
+args: ['WORKFLOW.LOG',]
+formatter: default
+
+[logger_root]
+level: WARNING
+handlers: console, logfile
+qualname: root
+propagate=0
+
+[logger_luigi-interface]
+level: DEBUG
+handlers: console, logfile
+qualname: luigi-interface
+propagate=0
+"""
